@@ -10,7 +10,7 @@ use POE::Component::Client::TCP;
 use constant TRACE => $ENV{'ICECAST_TRACE'} || 0;
 use constant DEBUG => $ENV{'ICECAST_DEBUG'} || 0;
 
-our $VERSION = 0.12;
+our $VERSION = 0.6;
 
 sub new {
 	my $type   = shift;
@@ -19,32 +19,25 @@ sub new {
 	my $mi     = $type.'->new()'; # hi, Rocco Caputto!
 	croak "$mi requires an even number of parameters" if @_ & 1;
 	
-	my $agent  = join('/', __PACKAGE__, $VERSION);
 	my $stream = $param->{'Stream'} ? _parse_stream_param($param->{'Stream'}) : {};
-	
-	my $host   = $stream->{'Host'} || $param->{'Host'} || croak "$mi requires Host param to stream";
 	my $path   = $stream->{'Path'} || $param->{'Path'} || croak "$mi requires Path param to stream";
 	   $path   = "/$path" unless $path =~ m{^/};
 	
 	POE::Component::Client::TCP->new(
-		(map { $_ => $stream->{$_} || $param->{$_} } 'RemoteAddress', 'RemotePort', 'BindAddress', 'BindPort'),
+		(map { $_ => $stream->{$_} || $param->{$_} } 'Alias', 'RemoteAddress', 'RemotePort', 'BindAddress', 'BindPort'),
 		
 		'Filter'        => POE::Filter::Stream->new,
 		'Connected'     => sub {
 			$_[HEAP]->{'server'}->put(grep { DEBUG && warn $_;1 } join "\n",
 				"GET $path HTTP/1.0",
-				"Host: $host",
-				"User-Agent: $agent",
-				'Accept: */*',
 				'Icy-MetaData: 1',
-				'Connection: close',
 				('') x 2
 			);
 		},
 		
 		'ServerInput'   => sub {
 			DEBUG && warn 'Server input ' . length $_[ARG0];
-			return unless my %tag = $_[ARG0] =~ /Stream(\w+)=([^;]+)/g;
+			return unless my %tag = $_[ARG0] =~ /Stream(\w+)='(.*?)';/g;
 			DEBUG && warn $tag{'Title'};
 			
 			{
@@ -62,8 +55,18 @@ sub new {
 			}
 		},
 		
-		'ConnectError'  => sub { croak "$mi has connect error:  ", join('  ', @_[ARG0..$#_]) },
-		'ServerError'   => sub { carp  "$mi has server  error:  ", join('  ', @_[ARG0..$#_]) },
+		'ConnectError'  => sub {
+			warn "$param->{'Stream'} connect error: " . $_[ARG2] . "\n";
+			
+			if ($param->{'Reconnect'}) {
+				DEBUG && warn "$mi will reconnect, delay is $param->{'Reconnect'}";
+				$_[KERNEL]->delay('reconnect' => $param->{'Reconnect'});
+			}
+		},
+		'ServerError'   => sub {
+			# XXX: can croak if args
+			warn "$param->{'Stream'} server error: " . $_[ARG0] . "\n";
+		},
 		
 		'SessionParams' => [ 'options' => { 'trace' => TRACE } ],
 	) or croak "$mi has error: $!";
@@ -76,10 +79,9 @@ sub _parse_stream_param {
 	
 	my($domain, $path) = $stream =~ m{^ http :// ([^/]+) / (.*) }x;
 	my($addr,   $port) = $domain =~ m{^ (.*) : (.*) }x;
-	
 	return {
-		'Host'          => $addr,
-		'RemoteAddress' => $addr,
+		'Host'          => $addr || $domain,
+		'RemoteAddress' => $addr || $domain,
 		'RemotePort'    => $port || 80,
 		'Path'          => $path,
 	};
@@ -274,9 +276,10 @@ L<http://search.cpan.org/dist/poe-component-client-icecast>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright (C) 2009 Anatoly Sharifulin
+Copyright (C) 2009-2011 Anatoly Sharifulin
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
 =cut
+
